#
# spec file for package python3-pydocstyle
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without test
Name:           python3-pydocstyle
Version:        2.1.1
Release:        150600.1.2
Summary:        Python docstring style checker
License:        MIT
Group:          Development/Languages/Python
Url:            https://github.com/PyCQA/pydocstyle/
Source:         https://files.pythonhosted.org/packages/source/p/pydocstyle/pydocstyle-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module snowballstemmer}
BuildRequires:  python-configparser
%endif
BuildRequires:  fdupes
Requires:       python3-six
Requires:       python3-snowballstemmer
%ifpython2
Requires:       python-configparser
%endif
Provides:       python3-pep257 = %{version}
Obsoletes:      python3-pep257 < %{version}
BuildArch:      noarch

%python_subpackages

%description
pydocstyle is a static analysis tool for checking compliance with
Python docstring conventions.

pydocstyle supports most of PEP 257 out of the box, but it should not
be considered a reference implementation.

The framework for checking docstring style is flexible, and custom
checks can be easily added, for example to cover NumPy docstring
conventions.

%prep
%setup -q -n pydocstyle-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/pydocstyle
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
mkdir empty
pushd empty
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitelib}
$python -c "import pydocstyle"
$python -c "from pydocstyle import *"
}
popd

%post
%python_install_alternative pydocstyle

%postun
%python_uninstall_alternative pydocstyle

%files %{python_files}
%defattr(-,root,root,-)
%doc README.rst
%license LICENSE-MIT
%python_alternative %{_bindir}/pydocstyle
%{python_sitelib}/*

%changelog
* Tue Jan 23 2024 alarrosa@suse.com
- Rename package to python3-pydocstyle so the 3.6 flavor can
  coexist with the python-pydocstyle package that builds the
  3.11 flavor
- Use update-alternatives
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Thu Jun  7 2018 toddrme2178@gmail.com
- Add missing dependency.
- Attempt to import as a basic test.
* Wed May  9 2018 toddrme2178@gmail.com
- Use license tag
* Wed Oct 18 2017 alarrosa@suse.com
- Update to version 2.1.1
- singlespec version
* Thu Jul  7 2016 toddrme2178@gmail.com
- Initial version
